from pylint.checkers import BaseChecker
from pylint.interfaces import IAstroidChecker

from .pylint_utils import module_contains_display

class ModuleDisplayChecker(BaseChecker):
    __implements__ = IAstroidChecker

    name = "module-display"
    priority = -1
    msgs = {
        "C4006": (
            "Production notebooks should not contain .display() or display() calls.",
            "module-contains-display",
            "Calling .display() or display() can clutter the module when running a pipeline.",
        ),
    }

    def __init__(self, linter=None):
        super(ModuleDisplayChecker, self).__init__(linter)
        self._function_stack = []

    def visit_functiondef(self, node):
        self._function_stack.append([])

    def visit_expr(self, node):
        if module_contains_display(node):
            self.add_message("module-contains-display", node=node)

    def leave_functiondef(self, node):
        self._function_stack.pop()



from .function_call_checker import FunctionCallChecker
from .logic_op_complexity_checker import LogicOpComplexityChecker
from .select_alias_checker import SelectAliasChecker
from .select_cast_checker import SelectCastChecker
from .chained_function_checker import ChainedDotFunctionsSyntaxChecker
from .confluence_page_checker import ConfluencePageChecker
from .author_checker import AuthorChecker
from .case_import_checker import CaseImportChecker
from .module_display_checker import ModuleDisplayChecker

def register(linter):
    linter.register_checker(FunctionCallChecker(linter))
    linter.register_checker(LogicOpComplexityChecker(linter))
    linter.register_checker(SelectAliasChecker(linter))
    linter.register_checker(SelectCastChecker(linter))
    linter.register_checker(ConfluencePageChecker(linter))
    linter.register_checker(ChainedDotFunctionsSyntaxChecker(linter))
    linter.register_checker(AuthorChecker(linter))
    linter.register_checker(CaseImportChecker(linter))
    linter.register_checker(ModuleDisplayChecker(linter))



from setuptools import find_packages, setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="pylint-pyspark",
    version="1.0.81",
    author="Aman Ankit",
    author_email="aman@astrumu.com",
    description="PySpark Style Guide",
    long_description="Built on Palantir's PySpark Style Guide, this is a guide to PySpark code style presenting common situations and the associated best practices based on the most frequent recurring topics across the PySpark repos we've encountered.",
    long_description_content_type="text/markdown",
    url="https://github.com/AstrumU/pylint-pyspark",
    packages=["pylint_pyspark"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=["pylint"],
)
 